@@ -7,9 +7,9 @@ use warnings;
 use Array::Iterator;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-26'; # DATE
+our $DATE = '2023-11-21'; # DATE
 our $DIST = 'Array-Iterator'; # DIST
-our $VERSION = '0.131'; # VERSION
+our $VERSION = '0.132'; # VERSION
 
 our @ISA = qw(Array::Iterator);
 
@@ -75,7 +75,7 @@ Array::Iterator::BiDirectional - A subclass of Array::Iterator to allow forwards
 
 =head1 VERSION
 
-This document describes version 0.131 of Array::Iterator::BiDirectional (from Perl distribution Array-Iterator), released on 2021-09-26.
+This document describes version 0.132 of Array::Iterator::BiDirectional (from Perl distribution Array-Iterator), released on 2023-11-21.
 
 =head1 SYNOPSIS
 
@@ -162,13 +162,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2017, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2021, 2017, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
