@@ -6,10 +6,10 @@ use warnings;
 
 use Array::Iterator;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-09-26'; # DATE
-our $DIST = 'Array-Iterator'; # DIST
-our $VERSION = '0.131'; # VERSION
+# AUTHORITY
+# DATE
+# DIST
+# VERSION
 
 our @ISA = qw(Array::Iterator);
 
@@ -61,21 +61,9 @@ sub get_loop_count {
 sub getLoopCount { my $self = shift; $self->get_loop_count(@_) }
 
 1;
-# ABSTRACT: A subclass of Array::Iterator to allow circular iteration
+#ABSTRACT: A subclass of Array::Iterator to allow circular iteration
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Array::Iterator::Circular - A subclass of Array::Iterator to allow circular iteration
-
-=head1 VERSION
-
-This document describes version 0.131 of Array::Iterator::Circular (from Perl distribution Array-Iterator), released on 2021-09-26.
+=for Pod::Coverage .+
 
 =head1 SYNOPSIS
 
@@ -105,8 +93,6 @@ This document describes version 0.131 of Array::Iterator::Circular (from Perl di
 
 This iterator will loop continuosly as long as C<next> or C<get_next> is called. The C<has_next> method will always return true (C<1>), since the list will always loop back. This is useful when you need a list to repeat itself, but don't want to (or care to) know that it is doing so.
 
-=for Pod::Coverage .+
-
 =head1 METHODS
 
 This is a subclass of Array::Iterator, only those methods that have been added or altered are documented here, refer to the Array::Iterator documentation for more information.
@@ -139,50 +125,14 @@ This method will tell you how many times the iterator has looped back to its sta
 
 =back
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Array-Iterator>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Array-Iterator>.
-
 =head1 SEE ALSO
 
 This is a subclass of B<Array::Iterator>, please refer to it for more documentation.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
 =head1 ORIGINAL AUTHOR
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
 
-=head1 CONTRIBUTING
-
-
-To contribute, you can send patches by email/via RT, or send pull requests on
-GitHub.
-
-Most of the time, you don't need to build the distribution yourself. You can
-simply modify the code, then test via:
-
- % prove -l
-
-If you want to build the distribution (e.g. to try to install it locally on your
-system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2017, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 ORIGINAL COPYRIGHT AND LICENSE
 
 Copyright 2004 by Infinity Interactive, Inc.
@@ -192,12 +142,4 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Array-Iterator>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =cut
